@@ -354,9 +354,11 @@ function prepare_rootfs_for_chroot()
 {
 	mount_pseudofilesystems
 
-	echo "Copying resolv.conf..."
-	cp -f /etc/resolv.conf "$REMASTER_DIR/etc/resolv.conf" ||
-		failure "Failed to copy resolv.conf, error=$?"
+	if [ ! -e "$REMASTER_DIR/etc/resolv.conf" ] ; then
+		echo "Copying resolv.conf..."
+		cp -f /etc/resolv.conf "$REMASTER_DIR/etc/resolv.conf" ||
+			failure "Failed to copy resolv.conf, error=$?"
+	fi
 		
 	echo "Copying fstab/mtab..."
 	if [ -f "$REMASTER_DIR/etc/fstab" ] ; then
@@ -390,6 +392,11 @@ function prepare_rootfs_for_chroot()
 	chroot "$REMASTER_DIR" mv /usr/sbin/update-grub /usr/sbin/update-grub.uck_blocked
 	chroot "$REMASTER_DIR" ln -s /bin/true /usr/sbin/update-grub
 
+	echo "Deactivating grub-probe..."
+	chroot "$REMASTER_DIR" mv /usr/sbin/grub-probe /usr/sbin/grub-probe.uck_blocked
+	chroot "$REMASTER_DIR" ln -s /bin/true /usr/sbin/grub-probe
+
+
 	echo "Remembering kernel update state..."
 	update_flags="reboot-required reboot-required.pkgs do-not-hibernate"
 	varrun="$REMASTER_DIR"/var/run
@@ -416,7 +423,11 @@ function clean_rootfs_after_chroot()
 	
 	echo "Reactivating update-grub..."
 	chroot "$REMASTER_DIR" rm /usr/sbin/update-grub
-	chroot "$REMASTER_DIR" mv /usr/sbin/update-grub.uck_blocked /usr/sbin/update-grub 
+	chroot "$REMASTER_DIR" mv /usr/sbin/update-grub.uck_blocked /usr/sbin/update-grub
+
+	echo "Reactivating update-grub..."
+	chroot "$REMASTER_DIR" rm /usr/sbin/grub-probe
+	chroot "$REMASTER_DIR" mv /usr/sbin/grub-probe.uck_blocked /usr/sbin/grub-probe
 	
 	UCK_USER_HOME_DIR=`xauth info|grep 'Authority file'| sed "s/[ \t]//g" | sed "s/\/\.Xauthority//" | cut -d ':' -f2`
 	if [ `echo $UCK_USER_HOME_DIR | cut -d '/' -f2` == 'home' ] ; then
@@ -427,8 +438,10 @@ function clean_rootfs_after_chroot()
 	echo "Removing generated machine uuid..."
 	chroot "$REMASTER_DIR" rm -f /var/lib/dbus/machine-id
 
-	echo "Removing generated resolv.conf..."
-	chroot "$REMASTER_DIR" rm -f /etc/resolv.conf
+	if [ ! -h "$REMASTER_DIR/etc/resolv.conf" ] ; then
+		echo "Removing generated resolv.conf..."
+		chroot "$REMASTER_DIR" rm -f /etc/resolv.conf
+	fi
 	
 	echo "Removing generated fstab/mtab..."
 	chroot "$REMASTER_DIR" rm -f /etc/mtab
